@@ -1,8 +1,7 @@
 package Person::ComplexAddress;
-our $VERSION = '1.100810';
 use warnings;
 use strict;
-use base 'Person::Base';
+use parent 'Person::Base';
 
 sub street {
     return $_[0]->{street} if @_ == 1;
