@@ -1,8 +1,7 @@
 package Person::SimpleAddress;
-our $VERSION = '1.100810';
 use warnings;
 use strict;
-use base 'Person::Base';
+use parent 'Person::Base';
 
 sub fulladdr {
     return $_[0]->{fulladdr} if @_ == 1;
